Module beta_api

Module beta_api 

Enums

GetGbfsFeedsError
struct for typed errors of method get_gbfs_feeds
GetGtfsFeedError
struct for typed errors of method get_gtfs_feed

Functions

get_gbfs_feeds
Get GBFS feeds from the Mobility Database.
get_gtfs_feed
Get the specified GTFS feed from the Mobility Database. Once a week, we check if the latest dataset has been updated and, if so, we update it in our system accordingly.