Module feeds_api

Module feeds_api 

Enums

GetFeedError
struct for typed errors of method get_feed
GetFeedsError
struct for typed errors of method get_feeds
GetGbfsFeedError
struct for typed errors of method get_gbfs_feed
GetGbfsFeedsError
struct for typed errors of method get_gbfs_feeds
GetGtfsFeedDatasetsError
struct for typed errors of method get_gtfs_feed_datasets
GetGtfsFeedError
struct for typed errors of method get_gtfs_feed
GetGtfsFeedGtfsRtFeedsError
struct for typed errors of method get_gtfs_feed_gtfs_rt_feeds
GetGtfsFeedsError
struct for typed errors of method get_gtfs_feeds
GetGtfsRtFeedError
struct for typed errors of method get_gtfs_rt_feed
GetGtfsRtFeedsError
struct for typed errors of method get_gtfs_rt_feeds

Functions

get_feed
Get the specified feed from the Mobility Database.
get_feeds
Get some (or all) feeds from the Mobility Database. The items are sorted by provider in alphabetical ascending order.
get_gbfs_feed
Get the specified GBFS feed from the Mobility Database.
get_gbfs_feeds
Get GBFS feeds from the Mobility Database.
get_gtfs_feed
Get the specified GTFS feed from the Mobility Database. Once a week, we check if the latest dataset has been updated and, if so, we update it in our system accordingly.
get_gtfs_feed_datasets
Get a list of datasets associated with a GTFS feed. Once a day, we check whether the latest dataset has changed; if it has, we update it in our system. The list is sorted from newest to oldest.
get_gtfs_feed_gtfs_rt_feeds
Get a list of GTFS Realtime related to a GTFS feed.
get_gtfs_feeds
Get some (or all) GTFS feeds from the Mobility Database.
get_gtfs_rt_feed
Get the specified GTFS Realtime feed from the Mobility Database.
get_gtfs_rt_feeds
Get some (or all) GTFS Realtime feeds from the Mobility Database.