Module search_api

Module search_api 

Enums

SearchFeedsError
struct for typed errors of method search_feeds

Functions

search_feeds
Search feeds on feed name, location and provider’s information.
The current implementation leverages the text search functionalities from PostgreSQL, in particulary plainto_tsquery.

Points to consider while using search endpoint:
- Operators are not currently supported. Operators are ignored as stop-words. - Search is based on lexemes(English) and case insensitive. The search_text_query_param is parsed and normalized much as for to_tsvector, then the & (AND) tsquery operator is inserted between surviving words. - The search will match all the lexemes with an AND operator. So, all lexemes must be present in the document. - Our current implementation only creates English lexemes. We are currently considering adding support to more languages. - The order of the words is not relevant for matching. The query New York should give you the same results as York New.

Example:
Query: New York Transit
Search Executed: ‘new’ & york & ‘transit’