pub struct BasicFeed {
pub id: Option<String>,
pub data_type: Option<DataType>,
pub created_at: Option<String>,
pub external_ids: Option<Vec<ExternalId>>,
pub provider: Option<String>,
pub feed_contact_email: Option<String>,
pub source_info: Option<Box<SourceInfo>>,
pub redirects: Option<Vec<Redirect>>,
}Fields
id: Option<String>Unique identifier used as a key for the feeds table.
data_type: Option<DataType>created_at: Option<String>The date and time the feed was added to the database, in ISO 8601 date-time format.
external_ids: Option<Vec<ExternalId>>The ID that can be use to find the feed data in an external or legacy database.
- JBDA: Automatically imported from http://docs.gtfs-data.jp/api.v2.html. Pattern is jbda-<organisation_id>-<feed_id>.
- TDG: Automatically imported from https://doc.transport.data.gouv.fr/outils/outils-disponibles-sur-le-pan/api. Pattern is tdg-<resource_id>.
- NTD: Automatically imported from https://www.transit.dot.gov/ntd/data-product/2023-annual-database-general-transit-feed-specification-gtfs-weblinks. Pattern is ntd-<ntd_id>.
- TransitFeeds: Automatically imported from old TransitFeeds website. Pattern is tfs-<feed_id>.
- Transit.land: Imported from https://www.transit.land/documentation/rest-api/feeds. Pattern is tld-<feed_id>.
provider: Option<String>A commonly used name for the transit provider included in the feed.
feed_contact_email: Option<String>Use to contact the feed producer.
source_info: Option<Box<SourceInfo>>redirects: Option<Vec<Redirect>>Implementations