pub struct BoundingBox {
pub minimum_latitude: Option<f64>,
pub maximum_latitude: Option<f64>,
pub minimum_longitude: Option<f64>,
pub maximum_longitude: Option<f64>,
}Expand description
BoundingBox : Bounding box of the dataset when it was first added to the catalog.
Fields
minimum_latitude: Option<f64>The minimum latitude for the dataset bounding box.
maximum_latitude: Option<f64>The maximum latitude for the dataset bounding box.
minimum_longitude: Option<f64>The minimum longitude for the dataset bounding box.
maximum_longitude: Option<f64>The maximum longitude for the dataset bounding box.
Implementations
Sourceimpl BoundingBox
impl BoundingBox
Sourcepub fn new() -> BoundingBox
pub fn new() -> BoundingBox
Bounding box of the dataset when it was first added to the catalog.