pub struct ExternalId {
pub external_id: Option<String>,
pub source: Option<String>,
}Fields
external_id: Option<String>The ID that can be used to find the feed data in an external or legacy database.
- JBDA: Automatically imported from http://docs.gtfs-data.jp/api.v2.html. Pattern is jbda-<organisation_id>-<feed_id>.
- TDG: Automatically imported from https://doc.transport.data.gouv.fr/outils/outils-disponibles-sur-le-pan/api. Pattern is tdg-<resource_id>.
- NTD: Automatically imported from https://www.transit.dot.gov/ntd/data-product/2023-annual-database-general-transit-feed-specification-gtfs-weblinks. Pattern is ntd-<ntd_id>.
- TransitFeeds: Automatically imported from old TransitFeeds website. Pattern is tfs-<feed_id>.
- Transit.land: Imported from https://www.transit.land/documentation/rest-api/feeds. Pattern is tld-<feed_id>.
source: Option<String>The source of the external ID, e.g. the name of the database where the external ID can be used.
Implementations
Sourceimpl ExternalId
impl ExternalId
pub fn new() -> ExternalId