Module feed

Module feed 

Structs

Feed

Enums

DataType
Status
Describes status of the Feed. Should be one of * active Feed should be used in public trip planners. * deprecated Feed is explicitly deprecated and should not be used in public trip planners. * inactive Feed hasn’t been recently updated and should be used at risk of providing outdated information. * development Feed is being used for development purposes and should not be used in public trip planners. * future Feed is not yet active but will be in the future.