pub struct GbfsVersion {
pub version: Option<String>,
pub created_at: Option<String>,
pub last_updated_at: Option<String>,
pub source: Option<Source>,
pub endpoints: Option<Vec<GbfsEndpoint>>,
pub latest_validation_report: Option<Box<GbfsValidationReport>>,
}Fields
version: Option<String>The version of the GBFS specification that the feed is using. This is a string that follows the semantic versioning format.
created_at: Option<String>The date when the GBFS version was saved to the database.
last_updated_at: Option<String>The date when the GBFS version was last updated in the database.
source: Option<Source>Indicates the origin of the version information. Possible values are: * autodiscovery: Retrieved directly from the main GBFS autodiscovery URL. * gbfs_versions: Retrieved from the gbfs_versions endpoint.
endpoints: Option<Vec<GbfsEndpoint>>A list of endpoints that are available in the version.
latest_validation_report: Option<Box<GbfsValidationReport>>Implementations
Sourceimpl GbfsVersion
impl GbfsVersion
pub fn new() -> GbfsVersion