LatestDataset

Struct LatestDataset 

pub struct LatestDataset {
    pub id: Option<String>,
    pub hosted_url: Option<String>,
    pub bounding_box: Option<Box<BoundingBox>>,
    pub downloaded_at: Option<String>,
    pub hash: Option<String>,
    pub service_date_range_start: Option<String>,
    pub service_date_range_end: Option<String>,
    pub agency_timezone: Option<String>,
    pub zipped_folder_size_mb: Option<f64>,
    pub unzipped_folder_size_mb: Option<f64>,
    pub validation_report: Option<Box<LatestDatasetValidationReport>>,
}

Fields

id: Option<String>

Identifier of the latest dataset for this feed.

hosted_url: Option<String>

As a convenience, the URL of the latest uploaded dataset hosted by MobilityData. It should be the same URL as the one found in the latest dataset id dataset. An alternative way to find this is to use the latest dataset id to obtain the dataset and then use its hosted_url.

bounding_box: Option<Box<BoundingBox>>downloaded_at: Option<String>

The date and time the dataset was downloaded from the producer, in ISO 8601 date-time format.

hash: Option<String>

A hash of the dataset.

service_date_range_start: Option<String>

The start date of the service date range for the dataset in UTC. Timing starts at 00:00:00 of the day.

service_date_range_end: Option<String>

The start date of the service date range for the dataset in UTC. Timing ends at 23:59:59 of the day.

agency_timezone: Option<String>

The timezone of the agency.

zipped_folder_size_mb: Option<f64>

The size of the zipped folder in MB.

unzipped_folder_size_mb: Option<f64>

The size of the unzipped folder in MB.

validation_report: Option<Box<LatestDatasetValidationReport>>

Implementations