pub struct LicenseWithRules {
pub id: Option<String>,
pub type: Option<String>,
pub is_spdx: Option<bool>,
pub name: Option<String>,
pub url: Option<String>,
pub description: Option<String>,
pub created_at: Option<String>,
pub updated_at: Option<String>,
pub license_rules: Option<Vec<LicenseRule>>,
}Fields
id: Option<String>Unique identifier for the license.
type: Option<String>The type of license.
is_spdx: Option<bool>true if license id spdx.
name: Option<String>The user facing name of the license.
url: Option<String>A URL where to find the license for the feed.
description: Option<String>The description of the license.
created_at: Option<String>The date and time the license was added to the database, in ISO 8601 date-time format.
updated_at: Option<String>The last date and time the license was updated in the database, in ISO 8601 date-time format.
license_rules: Option<Vec<LicenseRule>>Implementations
Sourceimpl LicenseWithRules
impl LicenseWithRules
pub fn new() -> LicenseWithRules