pub struct Location {
pub country_code: Option<String>,
pub country: Option<String>,
pub subdivision_name: Option<String>,
pub municipality: Option<String>,
}Fields
country_code: Option<String>ISO 3166-1 alpha-2 code designating the country where the system is located. For a list of valid codes see here.
country: Option<String>The english name of the country where the system is located.
subdivision_name: Option<String>ISO 3166-2 english subdivision name designating the subdivision (e.g province, state, region) where the system is located. For a list of valid names see here.
municipality: Option<String>Primary municipality in english in which the transit system is located.
Implementations