pub enum AuthenticationType {
Variant0,
Variant1,
Variant2,
}Expand description
Defines the type of authentication required to access the producer_url. Valid values for this field are: * 0 or (empty) - No authentication required. * 1 - The authentication requires an API key, which should be passed as value of the parameter api_key_parameter_name in the URL. Please visit URL in authentication_info_url for more information. * 2 - The authentication requires an HTTP header, which should be passed as the value of the header api_key_parameter_name in the HTTP request. When not provided, the authentication type is assumed to be 0.
Variants