SourceInfo

Struct SourceInfo 

pub struct SourceInfo {
    pub producer_url: Option<String>,
    pub authentication_type: Option<AuthenticationType>,
    pub authentication_info_url: Option<String>,
    pub api_key_parameter_name: Option<String>,
    pub license_url: Option<String>,
    pub license_id: Option<String>,
    pub license_is_spdx: Option<bool>,
    pub license_notes: Option<String>,
}

Fields

producer_url: Option<String>

URL where the producer is providing the dataset. Refer to the authentication information to know how to access this URL.

authentication_type: Option<AuthenticationType>

Defines the type of authentication required to access the producer_url. Valid values for this field are: * 0 or (empty) - No authentication required. * 1 - The authentication requires an API key, which should be passed as value of the parameter api_key_parameter_name in the URL. Please visit URL in authentication_info_url for more information. * 2 - The authentication requires an HTTP header, which should be passed as the value of the header api_key_parameter_name in the HTTP request. When not provided, the authentication type is assumed to be 0.

authentication_info_url: Option<String>

Contains a URL to a human-readable page describing how the authentication should be performed and how credentials can be created. This field is required for authentication_type=1 and authentication_type=2.

api_key_parameter_name: Option<String>

Defines the name of the parameter to pass in the URL to provide the API key. This field is required for authentication_type=1 and authentication_type=2.

license_url: Option<String>

A URL where to find the license for the feed.

license_id: Option<String>

Id of the feed license that can be used to query the license endpoint.

license_is_spdx: Option<bool>

true if the license is SPDX. false if not.

license_notes: Option<String>

Notes concerning the relation between the feed and the license.

Implementations