Enums
- GetGbfs
Feeds Error - struct for typed errors of method
get_gbfs_feeds - GetGtfs
Feed Error - struct for typed errors of method
get_gtfs_feed
Functions
- get_
gbfs_ feeds - Get GBFS feeds from the Mobility Database.
- get_
gtfs_ feed - Get the specified GTFS feed from the Mobility Database. Once a week, we check if the latest dataset has been updated and, if so, we update it in our system accordingly.