Enums
- GetFeed
Error - struct for typed errors of method
get_feed - GetFeeds
Error - struct for typed errors of method
get_feeds - GetGbfs
Feed Error - struct for typed errors of method
get_gbfs_feed - GetGbfs
Feeds Error - struct for typed errors of method
get_gbfs_feeds - GetGtfs
Feed Datasets Error - struct for typed errors of method
get_gtfs_feed_datasets - GetGtfs
Feed Error - struct for typed errors of method
get_gtfs_feed - GetGtfs
Feed Gtfs RtFeeds Error - struct for typed errors of method
get_gtfs_feed_gtfs_rt_feeds - GetGtfs
Feeds Error - struct for typed errors of method
get_gtfs_feeds - GetGtfs
RtFeed Error - struct for typed errors of method
get_gtfs_rt_feed - GetGtfs
RtFeeds Error - struct for typed errors of method
get_gtfs_rt_feeds
Functions
- get_
feed - Get the specified feed from the Mobility Database.
- get_
feeds - Get some (or all) feeds from the Mobility Database. The items are sorted by provider in alphabetical ascending order.
- get_
gbfs_ feed - Get the specified GBFS feed from the Mobility Database.
- get_
gbfs_ feeds - Get GBFS feeds from the Mobility Database.
- get_
gtfs_ feed - Get the specified GTFS feed from the Mobility Database. Once a week, we check if the latest dataset has been updated and, if so, we update it in our system accordingly.
- get_
gtfs_ feed_ datasets - Get a list of datasets associated with a GTFS feed. Once a day, we check whether the latest dataset has changed; if it has, we update it in our system. The list is sorted from newest to oldest.
- get_
gtfs_ feed_ gtfs_ rt_ feeds - Get a list of GTFS Realtime related to a GTFS feed.
- get_
gtfs_ feeds - Get some (or all) GTFS feeds from the Mobility Database.
- get_
gtfs_ rt_ feed - Get the specified GTFS Realtime feed from the Mobility Database.
- get_
gtfs_ rt_ feeds - Get some (or all) GTFS Realtime feeds from the Mobility Database.