pub struct Feed {Show 14 fields
pub id: Option<String>,
pub data_type: Option<DataType>,
pub created_at: Option<String>,
pub external_ids: Option<Vec<ExternalId>>,
pub provider: Option<String>,
pub feed_contact_email: Option<String>,
pub source_info: Option<Box<SourceInfo>>,
pub redirects: Option<Vec<Redirect>>,
pub status: Option<Status>,
pub official: Option<bool>,
pub official_updated_at: Option<String>,
pub feed_name: Option<String>,
pub note: Option<String>,
pub related_links: Option<Vec<FeedRelatedLink>>,
}Fields
id: Option<String>Unique identifier used as a key for the feeds table.
data_type: Option<DataType>created_at: Option<String>The date and time the feed was added to the database, in ISO 8601 date-time format.
external_ids: Option<Vec<ExternalId>>The ID that can be use to find the feed data in an external or legacy database.
- JBDA: Automatically imported from http://docs.gtfs-data.jp/api.v2.html. Pattern is jbda-<organisation_id>-<feed_id>.
- TDG: Automatically imported from https://doc.transport.data.gouv.fr/outils/outils-disponibles-sur-le-pan/api. Pattern is tdg-<resource_id>.
- NTD: Automatically imported from https://www.transit.dot.gov/ntd/data-product/2023-annual-database-general-transit-feed-specification-gtfs-weblinks. Pattern is ntd-<ntd_id>.
- TransitFeeds: Automatically imported from old TransitFeeds website. Pattern is tfs-<feed_id>.
- Transit.land: Imported from https://www.transit.land/documentation/rest-api/feeds. Pattern is tld-<feed_id>.
provider: Option<String>A commonly used name for the transit provider included in the feed.
feed_contact_email: Option<String>Use to contact the feed producer.
source_info: Option<Box<SourceInfo>>redirects: Option<Vec<Redirect>>status: Option<Status>Describes status of the Feed. Should be one of * active Feed should be used in public trip planners. * deprecated Feed is explicitly deprecated and should not be used in public trip planners. * inactive Feed hasn’t been recently updated and should be used at risk of providing outdated information. * development Feed is being used for development purposes and should not be used in public trip planners. * future Feed is not yet active but will be in the future.
official: Option<bool>A boolean value indicating if the feed is official or not. Official feeds are provided by the transit agency or a trusted source.
official_updated_at: Option<String>The date and time the official status was last updated, in ISO 8601 date-time format.
feed_name: Option<String>An optional description of the data feed, e.g to specify if the data feed is an aggregate of multiple providers, or which network is represented by the feed.
note: Option<String>A note to clarify complex use cases for consumers.
A list of related links for the feed.